@@ -36,7 +36,7 @@ sub init_plugins {
 		},
 
 		'XML::Simple' => {
-			RootName      => 'test',
+			RootName      => '<APP_NAME>',
 			NoAttr        => 1,
 			KeyAttr       => [],
 			SuppressEmpty => '' 
