@@ -1,8 +1,8 @@
 package Dwarf::Module::DSL;
 use Dwarf::Pragma;
+use Dwarf::Data::Validator;
 use Dwarf::Util qw/load_class dwarf_log/;
 use Carp qw/croak/;
-use Data::Validator;
 use Scalar::Util qw/weaken/;
 
 use Dwarf::Accessor {
@@ -79,32 +79,8 @@ sub dump          { shift->c->dump(@_) }
 
 sub args {
 	my ($self, $rules, $module, $args) = @_;
-
 	croak 'rules must be HashRef' unless ref $rules eq 'HASH';
-
-	for my $key (keys %$rules) {
-		next if ref $rules->{$key} eq 'HASH';
-
-		my $value = $rules->{$key};
-		my ($isa, $default) = split /\s*=\s*/, $value;
-		
-		$value = { isa => $isa };
-		$value->{default} = $default if $default;
-
-		if ($isa =~ m/^(.+)\?$/) {
-			$value->{isa} = $1;
-			$value->{optional} = 1;
-
-			# Optional でバリューが undef ならキー毎削除する
-			delete $args->{$key} unless defined $args->{$key};
-		}
-		
-		$rules->{$key} = $value;
-	}
-
-	my $validator = Data::Validator->new(%$rules)->with('NoRestricted');
-	my @ret = $validator->validate($args);
-	
+	my @ret = Dwarf::Data::Validator->validate($rules, $args);
 	return wantarray ? ($self, $ret[0]) : $ret[0];
 }
 
